@@ -24,16 +24,9 @@
 # exported function...
 pribor <- function(date = Sys.Date() - 1, maturity = "1D") {
 
-  network <- as.logical(Sys.getenv("NETWORK_UP", unset = TRUE)) # dummy variable to allow testing of network
   cnb <- as.logical(Sys.getenv("CNB_UP", unset = TRUE)) # dummy variable to allow testing of network
 
-
-  if (!curl::has_internet() | !network) { # network is down
-    message("No internet connection.")
-    return(NULL)
-  }
-
-  if (httr::http_error("https://www.cnb.cz/en/financial-markets/money-market/pribor/fixing-of-interest-rates-on-interbank-deposits-pribor/year.txt") | !cnb) { # CNB website down
+  if (!ok_to_proceed("https://www.cnb.cz/en/financial-markets/money-market/pribor/fixing-of-interest-rates-on-interbank-deposits-pribor/year.txt") | !cnb) { # CNB website down
     message("Data source broken.")
     return(NULL)
   }
@@ -47,7 +40,7 @@ pribor <- function(date = Sys.Date() - 1, maturity = "1D") {
 
   sazba <- paste0("PRIBOR_", maturity)
 
-  res <- lapply(roky, downloader) %>%
+  res <- lapply(roky, dnl_pribor) %>%
     dplyr::bind_rows() %>%
     dplyr::filter(date_valid %in% date) %>%
     dplyr::select(date_valid, !! sazba) %>%
@@ -56,23 +49,26 @@ pribor <- function(date = Sys.Date() - 1, maturity = "1D") {
 
   res
 
-}
+} # / exported function
 
 # downloader - a helper function to be l-applied
-downloader <- function(year) {
+dnl_pribor <- function(year) {
 
-  remote_path <- "https://www.cnb.cz/en/financial-markets/money-market/pribor/fixing-of-interest-rates-on-interbank-deposits-pribor/year.txt?year=" # remote archive
+
+  remote_path <- "https://www.cnb.cz/cs/financni-trhy/penezni-trh/pribor/fixing-urokovych-sazeb-na-mezibankovnim-trhu-depozit-pribor/rok.txt?year=" # remote archive
   remote_file <- paste0(remote_path, year) # path to ČNB source data
-  local_file <- file.path(tempdir(), paste0(year, ".txt")) # local file - in tempdir
+  local_file <- file.path(tempdir(), paste0("pr-", year, ".txt")) # local file - in tempdir
 
   if (!file.exists(local_file)) {
 
     # proceed to download via curl
     curl::curl_download(url = remote_file, destfile = local_file, quiet = T)
+    Sys.sleep(1/500)
   } # /if - local file exists
 
   local_df <- readr::read_delim(local_file,
                                 delim = "|", skip = 2,
+                                locale = readr::locale(decimal_mark = ","),
                                 col_names = c(
                                   "date_valid",
                                   "PRIBID_1D", "PRIBOR_1D",
@@ -86,7 +82,7 @@ downloader <- function(year) {
                                   "PRIBID_1Y", "PRIBOR_1Y"
                                 ),
                                 col_types = readr::cols(
-                                  date_valid = readr::col_date(format = "%d %b %Y"),
+                                  date_valid = readr::col_date(format = "%d.%m.%Y"),
                                   PRIBID_1D = readr::col_double(),
                                   PRIBOR_1D = readr::col_double(),
                                   PRIBID_1W = readr::col_double(),
@@ -108,6 +104,8 @@ downloader <- function(year) {
                                 )
   )
 
+  attr(local_df, 'spec') <- NULL
+
   local_df
 } # /function
 
